@@ -43,7 +43,6 @@
 #include "giomodule-priv.h"
 #include "gappinfo.h"
 
-#include "gioalias.h"
 
 /**
  * SECTION:gdesktopappinfo
@@ -699,18 +698,28 @@ expand_macro (char              macro,
       if (info->icon_name)
 	{
 	  g_string_append (exec, "--icon ");
-	  g_string_append (exec, info->icon_name);
+          expanded = g_shell_quote (info->icon_name);
+	  g_string_append (exec, expanded);
+          g_free (expanded);
 	}
       break;
 
     case 'c':
       if (info->name) 
-	g_string_append (exec, info->name);
+        {
+          expanded = g_shell_quote (info->name);
+	  g_string_append (exec, expanded);
+          g_free (expanded);
+        }
       break;
 
     case 'k':
       if (info->filename) 
-	g_string_append (exec, info->filename);
+        {
+          expanded = g_shell_quote (info->filename);
+	  g_string_append (exec, expanded);
+          g_free (expanded);
+        }
       break;
 
     case 'm': /* deprecated */
@@ -899,7 +908,7 @@ child_setup (gpointer user_data)
 
       g_setenv ("GIO_LAUNCHED_DESKTOP_FILE", data->desktop_file, TRUE);
 
-      g_snprintf (pid, 20, "%d", getpid ());
+      g_snprintf (pid, 20, "%ld", (long)getpid ());
       g_setenv ("GIO_LAUNCHED_DESKTOP_FILE_PID", pid, TRUE);
     }
 }
@@ -1646,7 +1655,7 @@ g_app_info_create_from_commandline (const char           *commandline,
   info->desktop_id = NULL;
   
   info->terminal = flags & G_APP_INFO_CREATE_NEEDS_TERMINAL;
-  info->startup_notify = FALSE;
+  info->startup_notify = flags & G_APP_INFO_CREATE_SUPPORTS_STARTUP_NOTIFICATION;
   info->hidden = FALSE;
   if (flags & G_APP_INFO_CREATE_SUPPORTS_URIS)
     info->exec = g_strconcat (commandline, " %u", NULL);
@@ -2706,6 +2715,3 @@ g_desktop_app_info_lookup_get_default_for_uri_scheme (GDesktopAppInfoLookup *loo
 
   return (* iface->get_default_for_uri_scheme) (lookup, uri_scheme);
 }
-
-#define __G_DESKTOP_APP_INFO_C__
-#include "gioaliasdef.c"
