@@ -56,7 +56,6 @@
 #include "glibintl.h"
 #include "gthemedicon.h"
 
-#include "gioalias.h"
 
 static const char *_resolve_dev_root (void);
 
@@ -243,18 +242,19 @@ g_unix_is_mount_path_system_internal (const char *mount_path)
     "/proc",
     "/sbin",
     "/net",
+    "/sys",
     NULL
   };
 
   if (is_in (mount_path, ignore_mountpoints))
     return TRUE;
   
-  if (g_str_has_prefix (mount_path, "/dev") ||
-      g_str_has_prefix (mount_path, "/proc") ||
-      g_str_has_prefix (mount_path, "/sys"))
+  if (g_str_has_prefix (mount_path, "/dev/") ||
+      g_str_has_prefix (mount_path, "/proc/") ||
+      g_str_has_prefix (mount_path, "/sys/"))
     return TRUE;
 
-  if (strstr (mount_path, "/.gvfs") != NULL)
+  if (g_str_has_suffix (mount_path, "/.gvfs"))
     return TRUE;
 
   return FALSE;
@@ -2191,6 +2191,3 @@ found:
   return real_dev_root;
 }
 #endif
-
-#define __G_UNIX_MOUNTS_C__
-#include "gioaliasdef.c"
